@@ -16,20 +16,28 @@ use Composer\Composer;
 use Composer\DependencyResolver\Request;
 use Composer\Installer;
 use Composer\IO\IOInterface;
+use Composer\Package\BasePackage;
 use Composer\Package\Loader\RootPackageLoader;
+use Composer\Package\PackageInterface;
+use Composer\Package\Version\VersionSelector;
 use Composer\Pcre\Preg;
 use Composer\Plugin\CommandEvent;
 use Composer\Plugin\PluginEvents;
 use Composer\Package\Version\VersionParser;
+use Composer\Repository\CompositeRepository;
+use Composer\Repository\PlatformRepository;
+use Composer\Repository\RepositoryInterface;
+use Composer\Repository\RepositorySet;
+use Composer\Semver\Constraint\MultiConstraint;
 use Composer\Semver\Intervals;
 use Composer\Util\HttpDownloader;
 use Composer\Advisory\Auditor;
+use Composer\Util\Platform;
 use Symfony\Component\Console\Helper\Table;
 use Symfony\Component\Console\Input\InputInterface;
 use Composer\Console\Input\InputOption;
 use Composer\Console\Input\InputArgument;
 use Symfony\Component\Console\Output\OutputInterface;
-use Symfony\Component\Console\Question\Question;
 
 /**
  * @author Jordi Boggiano <j.boggiano@seld.be>
@@ -75,8 +83,11 @@ class UpdateCommand extends BaseCommand
                 new InputOption('ignore-platform-reqs', null, InputOption::VALUE_NONE, 'Ignore all platform requirements (php & ext- packages).'),
                 new InputOption('prefer-stable', null, InputOption::VALUE_NONE, 'Prefer stable versions of dependencies (can also be set via the COMPOSER_PREFER_STABLE=1 env var).'),
                 new InputOption('prefer-lowest', null, InputOption::VALUE_NONE, 'Prefer lowest versions of dependencies (can also be set via the COMPOSER_PREFER_LOWEST=1 env var).'),
+                new InputOption('minimal-changes', 'm', InputOption::VALUE_NONE, 'During a partial update with -w/-W, only perform absolutely necessary changes to transitive dependencies (can also be set via the COMPOSER_MINIMAL_CHANGES=1 env var).'),
+                new InputOption('patch-only', null, InputOption::VALUE_NONE, 'Only allow patch version updates for currently installed dependencies.'),
                 new InputOption('interactive', 'i', InputOption::VALUE_NONE, 'Interactive interface with autocompletion to select the packages to update.'),
                 new InputOption('root-reqs', null, InputOption::VALUE_NONE, 'Restricts the update to your first degree dependencies.'),
+                new InputOption('bump-after-update', null, InputOption::VALUE_OPTIONAL, 'Runs bump after performing the update.', false, ['dev', 'no-dev', 'all']),
             ])
             ->setHelp(
                 <<<EOT
@@ -112,7 +123,7 @@ EOT
         ;
     }
 
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $io = $this->getIO();
         if ($input->getOption('dev')) {
@@ -160,7 +171,29 @@ EOT
             $parsedConstraint = $parser->parseConstraints($constraint);
             $temporaryConstraints[$package] = $parsedConstraint;
             if (isset($rootRequirements[$package]) && !Intervals::haveIntersections($parsedConstraint, $rootRequirements[$package]->getConstraint())) {
-                throw new \InvalidArgumentException('The temporary constraint "'.$constraint.'" for "'.$package.'" must be a subset of the constraint in your composer.json ('.$rootRequirements[$package]->getPrettyConstraint().')');
+                $io->writeError('<error>The temporary constraint "'.$constraint.'" for "'.$package.'" must be a subset of the constraint in your composer.json ('.$rootRequirements[$package]->getPrettyConstraint().')</error>');
+                $io->write('<info>Run `composer require '.$package.'` or `composer require '.$package.':'.$constraint.'` instead to replace the constraint</info>');
+                return self::FAILURE;
+            }
+        }
+
+        if ($input->getOption('patch-only')) {
+            if (!$composer->getLocker()->isLocked()) {
+                throw new \InvalidArgumentException('patch-only can only be used with a lock file present');
+            }
+            foreach ($composer->getLocker()->getLockedRepository(true)->getCanonicalPackages() as $package) {
+                if ($package->isDev()) {
+                    continue;
+                }
+                if (!Preg::isMatch('{^(\d+\.\d+\.\d+)}', $package->getVersion(), $match)) {
+                    continue;
+                }
+                $constraint = $parser->parseConstraints('~'.$match[1]);
+                if (isset($temporaryConstraints[$package->getName()])) {
+                    $temporaryConstraints[$package->getName()] = MultiConstraint::create([$temporaryConstraints[$package->getName()], $constraint], true);
+                } else {
+                    $temporaryConstraints[$package->getName()] = $constraint;
+                }
             }
         }
 
@@ -238,13 +271,35 @@ EOT
             ->setTemporaryConstraints($temporaryConstraints)
             ->setAudit(!$input->getOption('no-audit'))
             ->setAuditFormat($this->getAuditFormat($input))
+            ->setMinimalUpdate($input->getOption('minimal-changes'))
         ;
 
         if ($input->getOption('no-plugins')) {
             $install->disablePlugins();
         }
 
-        return $install->run();
+        $result = $install->run();
+
+        if ($result === 0) {
+            $bumpAfterUpdate = $input->getOption('bump-after-update');
+            if (false === $bumpAfterUpdate) {
+                $bumpAfterUpdate = $composer->getConfig()->get('bump-after-update');
+            }
+
+            if (false !== $bumpAfterUpdate) {
+                $io->writeError('<info>Bumping dependencies</info>');
+                $bumpCommand = new BumpCommand();
+                $bumpCommand->setComposer($composer);
+                $result = $bumpCommand->doBump(
+                    $io,
+                    $bumpAfterUpdate === 'dev',
+                    $bumpAfterUpdate === 'no-dev',
+                    $input->getOption('dry-run'),
+                    $input->getArgument('packages')
+                );
+            }
+        }
+        return $result;
     }
 
     /**
@@ -257,46 +312,53 @@ EOT
             throw new \InvalidArgumentException('--interactive cannot be used in non-interactive terminals.');
         }
 
+        $platformReqFilter = $this->getPlatformRequirementFilter($input);
+        $stabilityFlags = $composer->getPackage()->getStabilityFlags();
         $requires = array_merge(
             $composer->getPackage()->getRequires(),
             $composer->getPackage()->getDevRequires()
         );
+
+        $filter = \count($packages) > 0 ? BasePackage::packageNamesToRegexp($packages) : null;
+
+        $io->writeError('<info>Loading packages that can be updated...</info>');
         $autocompleterValues = [];
-        foreach ($requires as $require) {
-            $target = $require->getTarget();
-            $autocompleterValues[strtolower($target)] = $target;
-        }
-
-        $installedPackages = $composer->getRepositoryManager()->getLocalRepository()->getPackages();
+        $installedPackages = $composer->getLocker()->isLocked() ? $composer->getLocker()->getLockedRepository(true)->getPackages() : $composer->getRepositoryManager()->getLocalRepository()->getPackages();
+        $versionSelector = $this->createVersionSelector($composer);
         foreach ($installedPackages as $package) {
-            $autocompleterValues[$package->getName()] = $package->getPrettyName();
+            if ($filter !== null && !Preg::isMatch($filter, $package->getName())) {
+                continue;
+            }
+            $currentVersion = $package->getPrettyVersion();
+            $constraint = isset($requires[$package->getName()]) ? $requires[$package->getName()]->getPrettyConstraint() : null;
+            $stability = isset($stabilityFlags[$package->getName()]) ? (string) array_search($stabilityFlags[$package->getName()], BasePackage::STABILITIES, true) : $composer->getPackage()->getMinimumStability();
+            $latestVersion = $versionSelector->findBestCandidate($package->getName(), $constraint, $stability, $platformReqFilter);
+            if ($latestVersion !== false && ($package->getVersion() !== $latestVersion->getVersion() || $latestVersion->isDev())) {
+                $autocompleterValues[$package->getName()] = '<comment>' . $currentVersion . '</comment> => <comment>' . $latestVersion->getPrettyVersion() . '</comment>';
+            }
+        }
+        if (0 === \count($installedPackages)) {
+            foreach ($requires as $req => $constraint) {
+                if (PlatformRepository::isPlatformPackage($req)) {
+                    continue;
+                }
+                $autocompleterValues[$req] = '';
+            }
         }
 
-        $helper = $this->getHelper('question');
-        $question = new Question('<comment>Enter package name: </comment>', null);
-
-        $io->writeError('<info>Press enter without value to end submission</info>');
-
-        do {
-            $autocompleterValues = array_diff($autocompleterValues, $packages);
-            $question->setAutocompleterValues($autocompleterValues);
-            $addedPackage = $helper->ask($input, $output, $question);
-
-            if (!is_string($addedPackage) || empty($addedPackage)) {
-                break;
-            }
-
-            $addedPackage = strtolower($addedPackage);
-            if (!in_array($addedPackage, $packages)) {
-                $packages[] = $addedPackage;
-            }
-        } while (true);
-
-        $packages = array_filter($packages);
-        if (!$packages) {
-            throw new \InvalidArgumentException('You must enter minimum one package.');
+        if (0 === \count($autocompleterValues)) {
+            throw new \RuntimeException('Could not find any package with new versions available');
         }
 
+        $packages = $io->select(
+            'Select packages: (Select more than one value separated by comma) ',
+            $autocompleterValues,
+            false,
+            1,
+            'No package named "%s" is installed.',
+            true
+        );
+
         $table = new Table($output);
         $table->setHeaders(['Selected packages']);
         foreach ($packages as $package) {
@@ -313,4 +375,14 @@ EOT
 
         throw new \RuntimeException('Installation aborted.');
     }
+
+    private function createVersionSelector(Composer $composer): VersionSelector
+    {
+        $repositorySet = new RepositorySet();
+        $repositorySet->addRepository(new CompositeRepository(array_filter($composer->getRepositoryManager()->getRepositories(), function (RepositoryInterface $repository) {
+            return !$repository instanceof PlatformRepository;
+        })));
+
+        return new VersionSelector($repositorySet);
+    }
 }
