@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -26,9 +26,9 @@ class ArrayDumper
     /**
      * @return array<string, mixed>
      */
-    public function dump(PackageInterface $package)
+    public function dump(PackageInterface $package): array
     {
-        $keys = array(
+        $keys = [
             'binaries' => 'bin',
             'type',
             'extra',
@@ -37,18 +37,19 @@ class ArrayDumper
             'devAutoload' => 'autoload-dev',
             'notificationUrl' => 'notification-url',
             'includePaths' => 'include-path',
-        );
+            'phpExt' => 'php-ext',
+        ];
 
-        $data = array();
+        $data = [];
         $data['name'] = $package->getPrettyName();
         $data['version'] = $package->getPrettyVersion();
         $data['version_normalized'] = $package->getVersion();
 
-        if ($package->getTargetDir()) {
+        if ($package->getTargetDir() !== null) {
             $data['target-dir'] = $package->getTargetDir();
         }
 
-        if ($package->getSourceType()) {
+        if ($package->getSourceType() !== null) {
             $data['source']['type'] = $package->getSourceType();
             $data['source']['url'] = $package->getSourceUrl();
             if (null !== ($value = $package->getSourceReference())) {
@@ -59,7 +60,7 @@ class ArrayDumper
             }
         }
 
-        if ($package->getDistType()) {
+        if ($package->getDistType() !== null) {
             $data['dist']['type'] = $package->getDistType();
             $data['dist']['url'] = $package->getDistUrl();
             if (null !== ($value = $package->getDistReference())) {
@@ -74,20 +75,23 @@ class ArrayDumper
         }
 
         foreach (BasePackage::$supportedLinkTypes as $type => $opts) {
-            if ($links = $package->{'get'.ucfirst($opts['method'])}()) {
-                foreach ($links as $link) {
-                    $data[$type][$link->getTarget()] = $link->getPrettyConstraint();
-                }
-                ksort($data[$type]);
+            $links = $package->{'get'.ucfirst($opts['method'])}();
+            if (\count($links) === 0) {
+                continue;
             }
+            foreach ($links as $link) {
+                $data[$type][$link->getTarget()] = $link->getPrettyConstraint();
+            }
+            ksort($data[$type]);
         }
 
-        if ($packages = $package->getSuggests()) {
+        $packages = $package->getSuggests();
+        if (\count($packages) > 0) {
             ksort($packages);
             $data['suggest'] = $packages;
         }
 
-        if ($package->getReleaseDate()) {
+        if ($package->getReleaseDate() instanceof \DateTimeInterface) {
             $data['time'] = $package->getReleaseDate()->format(DATE_RFC3339);
         }
 
@@ -105,7 +109,7 @@ class ArrayDumper
                 $data['archive']['exclude'] = $package->getArchiveExcludes();
             }
 
-            $keys = array(
+            $keys = [
                 'scripts',
                 'license',
                 'authors',
@@ -115,7 +119,7 @@ class ArrayDumper
                 'repositories',
                 'support',
                 'funding',
-            );
+            ];
 
             $data = $this->dumpValues($package, $keys, $data);
 
@@ -130,7 +134,7 @@ class ArrayDumper
 
         if ($package instanceof RootPackageInterface) {
             $minimumStability = $package->getMinimumStability();
-            if ($minimumStability) {
+            if ($minimumStability !== '') {
                 $data['minimum-stability'] = $minimumStability;
             }
         }
@@ -148,7 +152,7 @@ class ArrayDumper
      *
      * @return array<string, mixed>
      */
-    private function dumpValues(PackageInterface $package, array $keys, array $data)
+    private function dumpValues(PackageInterface $package, array $keys, array $data): array
     {
         foreach ($keys as $method => $key) {
             if (is_numeric($method)) {
@@ -156,7 +160,7 @@ class ArrayDumper
             }
 
             $getter = 'get'.ucfirst($method);
-            $value = $package->$getter();
+            $value = $package->{$getter}();
 
             if (null !== $value && !(\is_array($value) && 0 === \count($value))) {
                 $data[$key] = $value;
