@@ -65,14 +65,14 @@ class GitLab
         }
 
         // if available use token from git config
-        if (0 === $this->process->execute('git config gitlab.accesstoken', $output)) {
+        if (0 === $this->process->execute(['git', 'config', 'gitlab.accesstoken'], $output)) {
             $this->io->setAuthentication($originUrl, trim($output), 'oauth2');
 
             return true;
         }
 
         // if available use deploy token from git config
-        if (0 === $this->process->execute('git config gitlab.deploytoken.user', $tokenUser) && 0 === $this->process->execute('git config gitlab.deploytoken.token', $tokenPassword)) {
+        if (0 === $this->process->execute(['git', 'config', 'gitlab.deploytoken.user'], $tokenUser) && 0 === $this->process->execute(['git', 'config', 'gitlab.deploytoken.token'], $tokenPassword)) {
             $this->io->setAuthentication($originUrl, trim($tokenUser), trim($tokenPassword));
 
             return true;
@@ -126,9 +126,16 @@ class GitLab
         }
 
         $localAuthConfig = $this->config->getLocalAuthConfigSource();
+        $personalAccessTokenLink = $scheme.'://'.$originUrl.'/-/profile/personal_access_tokens';
+        $revokeLink = $scheme.'://'.$originUrl.'/-/profile/applications';
         $this->io->writeError(sprintf('A token will be created and stored in "%s", your password will never be stored', ($localAuthConfig !== null ? $localAuthConfig->getName() . ' OR ' : '') . $this->config->getAuthConfigSource()->getName()));
-        $this->io->writeError('To revoke access to this token you can visit '.$scheme.'://'.$originUrl.'/-/profile/applications');
-        $this->io->writeError('Alternatively you can setup an personal access token on  '.$scheme.'://'.$originUrl.'/-/profile/personal_access_tokens and store it under "gitlab-token" see https://getcomposer.org/doc/articles/authentication-for-private-packages.md#gitlab-token for more details.');
+        $this->io->writeError('To revoke access to this token you can visit:');
+        $this->io->writeError($revokeLink);
+        $this->io->writeError('Alternatively you can setup an personal access token on:');
+        $this->io->writeError($personalAccessTokenLink);
+        $this->io->writeError('and store it under "gitlab-token" see https://getcomposer.org/doc/articles/authentication-for-private-packages.md#gitlab-token for more details.');
+        $this->io->writeError('https://getcomposer.org/doc/articles/authentication-for-private-packages.md#gitlab-token');
+        $this->io->writeError('for more details.');
 
         $storeInLocalAuthConfig = false;
         if ($localAuthConfig !== null) {
@@ -155,7 +162,8 @@ class GitLab
                         $this->io->writeError('Maximum number of login attempts exceeded. Please try again later.');
                     }
 
-                    $this->io->writeError('You can also manually create a personal access token enabling the "read_api" scope at '.$scheme.'://'.$originUrl.'/profile/personal_access_tokens');
+                    $this->io->writeError('You can also manually create a personal access token enabling the "read_api" scope at:');
+                    $this->io->writeError($scheme.'://'.$originUrl.'/profile/personal_access_tokens');
                     $this->io->writeError('Add it using "composer config --global --auth gitlab-token.'.$originUrl.' <token>"');
 
                     continue;
