@@ -15,7 +15,6 @@ namespace Composer\Test\Advisory;
 use Composer\Advisory\PartialSecurityAdvisory;
 use Composer\Advisory\SecurityAdvisory;
 use Composer\IO\BufferIO;
-use Composer\IO\NullIO;
 use Composer\Package\CompletePackage;
 use Composer\Package\Package;
 use Composer\Package\Version\VersionParser;
@@ -23,7 +22,6 @@ use Composer\Repository\ComposerRepository;
 use Composer\Repository\RepositorySet;
 use Composer\Test\TestCase;
 use Composer\Advisory\Auditor;
-use Composer\Util\Platform;
 use InvalidArgumentException;
 
 class AuditorTest extends TestCase
@@ -162,7 +160,8 @@ Found 2 abandoned packages:
         self::assertSame($output, trim(str_replace("\r", '', $io->getOutput())));
     }
 
-    public function ignoredIdsProvider(): \Generator {
+    public function ignoredIdsProvider(): \Generator
+    {
         yield 'ignore by CVE' => [
             [
                 new Package('vendor1/package1', '3.0.0.0', '3.0.0'),
@@ -178,7 +177,7 @@ Found 2 abandoned packages:
                 ['text' => 'URL: https://advisory.example.com/advisory1'],
                 ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
                 ['text' => 'Reported at: 2022-05-25T13:21:00+00:00'],
-            ]
+            ],
         ];
         yield 'ignore by CVE with reasoning' => [
             [
@@ -196,7 +195,7 @@ Found 2 abandoned packages:
                 ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
                 ['text' => 'Reported at: 2022-05-25T13:21:00+00:00'],
                 ['text' => 'Ignore reason: A good reason'],
-            ]
+            ],
         ];
         yield 'ignore by advisory id' => [
             [
@@ -213,7 +212,7 @@ Found 2 abandoned packages:
                 ['text' => 'URL: https://advisory.example.com/advisory2'],
                 ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
                 ['text' => 'Reported at: 2022-05-25T13:21:00+00:00'],
-            ]
+            ],
         ];
         yield 'ignore by remote id' => [
             [
@@ -230,7 +229,7 @@ Found 2 abandoned packages:
                 ['text' => 'URL: https://advisory.example.com/advisory17'],
                 ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
                 ['text' => 'Reported at: 2015-05-25T13:21:00+00:00'],
-            ]
+            ],
         ];
         yield '1 vulnerability, 0 ignored' => [
             [
@@ -247,7 +246,7 @@ Found 2 abandoned packages:
                 ['text' => 'URL: https://advisory.example.com/advisory1'],
                 ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
                 ['text' => 'Reported at: 2022-05-25T13:21:00+00:00'],
-            ]
+            ],
         ];
         yield '1 vulnerability, 3 ignored affecting 2 packages' => [
             [
@@ -295,7 +294,7 @@ Found 2 abandoned packages:
                 ['text' => 'URL: https://advisory.example.com/advisory7'],
                 ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
                 ['text' => 'Reported at: 2015-05-25T13:21:00+00:00'],
-            ]
+            ],
         ];
     }
 
@@ -314,6 +313,55 @@ Found 2 abandoned packages:
         self::assertSame($exitCode, $result);
     }
 
+    public function ignoreSeverityProvider(): \Generator
+    {
+        yield 'ignore medium' => [
+            [
+                new Package('vendor1/package1', '2.0.0.0', '2.0.0'),
+            ],
+            ['medium'],
+            1,
+            [
+                ['text' => 'Found 2 ignored security vulnerability advisories affecting 1 package:'],
+            ],
+        ];
+        yield 'ignore high' => [
+            [
+                new Package('vendor1/package1', '2.0.0.0', '2.0.0'),
+            ],
+            ['high'],
+            1,
+            [
+                ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
+            ],
+        ];
+        yield 'ignore high and medium' => [
+            [
+                new Package('vendor1/package1', '2.0.0.0', '2.0.0'),
+            ],
+            ['high', 'medium'],
+            0,
+            [
+                ['text' => 'Found 3 ignored security vulnerability advisories affecting 1 package:'],
+            ],
+        ];
+    }
+
+    /**
+     * @dataProvider ignoreSeverityProvider
+     * @phpstan-param array<\Composer\Package\Package> $packages
+     * @phpstan-param array<string> $ignoredSeverities
+     * @phpstan-param 0|positive-int $exitCode
+     * @phpstan-param list<array{text: string, verbosity?: \Composer\IO\IOInterface::*, regex?: true}|array{ask: string, reply: string}|array{auth: array{string, string, string|null}}> $expectedOutput
+     */
+    public function testAuditWithIgnoreSeverity($packages, $ignoredSeverities, $exitCode, $expectedOutput): void
+    {
+        $auditor = new Auditor();
+        $result = $auditor->audit($io = $this->getIOMock(), $this->getRepoSet(), $packages, Auditor::FORMAT_PLAIN, false, [], Auditor::ABANDONED_IGNORE, $ignoredSeverities);
+        $io->expects($expectedOutput, true);
+        self::assertSame($exitCode, $result);
+    }
+
     private function getRepoSet(): RepositorySet
     {
         $repo = $this
